@@ -634,7 +634,7 @@ def check_all(cli_args: typing.Optional[typing.Sequence[str]] = None
     results: typing.Dict[str, typing.Tuple[bool, str]] = {}
 
     perform_test('python_version', check_python_version, results)
-    perform_test('install_directory', check_install_directory, results)
+    #perform_test('install_directory', check_install_directory, results)
     perform_test('numpy', check_numpy, results)
     perform_test('scipy', check_scipy, results)
     perform_test('matplotlib', check_matplotlib, results)
